@@ -50,7 +50,46 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:BOOLEAN,INT (./libanjuta-iface-marshallers.list:1) */
+/* BOOLEAN:OBJECT (./libanjuta-iface-marshallers.list:1) */
+void
+libanjuta_iface_cclosure_marshal_BOOLEAN__OBJECT (GClosure     *closure,
+                                                  GValue       *return_value G_GNUC_UNUSED,
+                                                  guint         n_param_values,
+                                                  const GValue *param_values,
+                                                  gpointer      invocation_hint G_GNUC_UNUSED,
+                                                  gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT) (gpointer     data1,
+                                                    gpointer     arg_1,
+                                                    gpointer     data2);
+  register GMarshalFunc_BOOLEAN__OBJECT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_object (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* VOID:BOOLEAN,INT (./libanjuta-iface-marshallers.list:2) */
 void
 libanjuta_iface_cclosure_marshal_VOID__BOOLEAN_INT (GClosure     *closure,
                                                     GValue       *return_value G_GNUC_UNUSED,
@@ -87,13 +126,13 @@ libanjuta_iface_cclosure_marshal_VOID__BOOLEAN_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED (./libanjuta-iface-marshallers.list:2) */
+/* VOID:BOXED (./libanjuta-iface-marshallers.list:3) */
 
-/* VOID:ENUM (./libanjuta-iface-marshallers.list:3) */
+/* VOID:ENUM (./libanjuta-iface-marshallers.list:4) */
 
-/* VOID:INT (./libanjuta-iface-marshallers.list:4) */
+/* VOID:INT (./libanjuta-iface-marshallers.list:5) */
 
-/* VOID:INT,INT (./libanjuta-iface-marshallers.list:5) */
+/* VOID:INT,INT (./libanjuta-iface-marshallers.list:6) */
 void
 libanjuta_iface_cclosure_marshal_VOID__INT_INT (GClosure     *closure,
                                                 GValue       *return_value G_GNUC_UNUSED,
@@ -130,7 +169,7 @@ libanjuta_iface_cclosure_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT,ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:6) */
+/* VOID:INT,INT,ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:7) */
 void
 libanjuta_iface_cclosure_marshal_VOID__INT_INT_ULONG_STRING_UINT (GClosure     *closure,
                                                                   GValue       *return_value G_GNUC_UNUSED,
@@ -173,9 +212,9 @@ libanjuta_iface_cclosure_marshal_VOID__INT_INT_ULONG_STRING_UINT (GClosure     *
             data2);
 }
 
-/* VOID:OBJECT (./libanjuta-iface-marshallers.list:7) */
+/* VOID:OBJECT (./libanjuta-iface-marshallers.list:8) */
 
-/* VOID:OBJECT,BOOLEAN,INT,INT,STRING (./libanjuta-iface-marshallers.list:8) */
+/* VOID:OBJECT,BOOLEAN,INT,INT,STRING (./libanjuta-iface-marshallers.list:9) */
 void
 libanjuta_iface_cclosure_marshal_VOID__OBJECT_BOOLEAN_INT_INT_STRING (GClosure     *closure,
                                                                       GValue       *return_value G_GNUC_UNUSED,
@@ -218,7 +257,7 @@ libanjuta_iface_cclosure_marshal_VOID__OBJECT_BOOLEAN_INT_INT_STRING (GClosure
             data2);
 }
 
-/* VOID:OBJECT,CHAR (./libanjuta-iface-marshallers.list:9) */
+/* VOID:OBJECT,CHAR (./libanjuta-iface-marshallers.list:10) */
 void
 libanjuta_iface_cclosure_marshal_VOID__OBJECT_CHAR (GClosure     *closure,
                                                     GValue       *return_value G_GNUC_UNUSED,
@@ -255,9 +294,46 @@ libanjuta_iface_cclosure_marshal_VOID__OBJECT_CHAR (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER (./libanjuta-iface-marshallers.list:10) */
+/* VOID:OBJECT,STRING (./libanjuta-iface-marshallers.list:11) */
+void
+libanjuta_iface_cclosure_marshal_VOID__OBJECT_STRING (GClosure     *closure,
+                                                      GValue       *return_value G_GNUC_UNUSED,
+                                                      guint         n_param_values,
+                                                      const GValue *param_values,
+                                                      gpointer      invocation_hint G_GNUC_UNUSED,
+                                                      gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer     data1,
+                                                    gpointer     arg_1,
+                                                    gpointer     arg_2,
+                                                    gpointer     data2);
+  register GMarshalFunc_VOID__OBJECT_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
 
-/* VOID:POINTER,BOXED (./libanjuta-iface-marshallers.list:11) */
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__OBJECT_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_object (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            data2);
+}
+
+/* VOID:POINTER (./libanjuta-iface-marshallers.list:12) */
+
+/* VOID:POINTER,BOXED (./libanjuta-iface-marshallers.list:13) */
 void
 libanjuta_iface_cclosure_marshal_VOID__POINTER_BOXED (GClosure     *closure,
                                                       GValue       *return_value G_GNUC_UNUSED,
@@ -294,9 +370,9 @@ libanjuta_iface_cclosure_marshal_VOID__POINTER_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING (./libanjuta-iface-marshallers.list:12) */
+/* VOID:STRING (./libanjuta-iface-marshallers.list:14) */
 
-/* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:13) */
+/* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:15) */
 void
 libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                       GValue       *return_value G_GNUC_UNUSED,
@@ -333,7 +409,7 @@ libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:14) */
+/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:16) */
 void
 libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
                                                  GValue       *return_value G_GNUC_UNUSED,
@@ -370,7 +446,7 @@ libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:15) */
+/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:17) */
 void
 libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
                                                           GValue       *return_value G_GNUC_UNUSED,
@@ -409,5 +485,5 @@ libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:VOID (./libanjuta-iface-marshallers.list:16) */
+/* VOID:VOID (./libanjuta-iface-marshallers.list:18) */
 
